==> location-0.1.3-sources.jar: com/locnavi/location/xunjimap/XJLocation.java <==
package com.locnavi.location.xunjimap;

/**
 * author:chen
 * time:2017/5/16
 * desc:
 */
public class XJLocation {

    private boolean inThisMap;
    private String floor;
    private String floorDescription;
    private String nearLocationRegion ;
    private Double latitude ;
    private Double longitude ;

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }


//    double latitude = sails.getLatitude();
//    double longitude = sails.getLongitude();


    public String getNearLocationRegion() {
        return nearLocationRegion;
    }

    public void setNearLocationRegion(String nearLocationRegion) {
        this.nearLocationRegion = nearLocationRegion;
    }

    public boolean isInThisMap() {
        return inThisMap;
    }

    public void setInThisMap(boolean inThisMap) {
        this.inThisMap = inThisMap;
    }

    public String getFloor() {
        return floor;
    }

    public void setFloor(String floor) {
        this.floor = floor;
    }

    public String getFloorDescription() {
        return floorDescription;
    }

    public void setFloorDescription(String floorDescription) {
        this.floorDescription = floorDescription;
    }

    @Override
    public String toString() {
        return "XJLocation{" +
                "inThisMap=" + inThisMap +
                ", floor='" + floor + '\'' +
                ", floorDescription='" + floorDescription + '\'' +
                ", nearLocationRegion='" + nearLocationRegion + '\'' +
                ", latitude=" + latitude +
                ", longitude=" + longitude +
                '}';
    }
}

==> location-1.2.5-sources.jar: com/locnavi/location/xunjimap/XJLocation.java <==
package com.locnavi.location.xunjimap;

import java.util.List;

/**
 * author:chen
 * time:2017/5/16
 * desc:
 */
public class XJLocation {

    private boolean inThisMap;
    private String floor;
    private String floorDescription;
    private String nearLocationRegion;
    private String buildingName;
    private Double latitude;
    private Double longitude;
    private List<String> currentRegions;

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }


    public String getNearLocationRegion() {
        return nearLocationRegion;
    }

    public void setNearLocationRegion(String nearLocationRegion) {
        this.nearLocationRegion = nearLocationRegion;
    }

    public boolean isInThisMap() {
        return inThisMap;
    }

    public void setInThisMap(boolean inThisMap) {
        this.inThisMap = inThisMap;
    }

    public String getFloor() {
        return floor;
    }

    public void setFloor(String floor) {
        this.floor = floor;
    }

    public String getFloorDescription() {
        return floorDescription;
    }

    public void setFloorDescription(String floorDescription) {
        this.floorDescription = floorDescription;
    }

    public String getBuildingName() {
        return buildingName;
    }

    public void setBuildingName(String buildingName) {
        this.buildingName = buildingName;
    }

    public List<String> getCurrentRegions() {
        return currentRegions;
    }

    public void setCurrentRegions(List<String> currentRegions) {
        this.currentRegions = currentRegions;
    }

    @Override
    public String toString() {
        return "XJLocation{" +
                "inThisMap=" + inThisMap +
                ", floor='" + floor + '\'' +
                ", floorDescription='" + floorDescription + '\'' +
                ", nearLocationRegion='" + nearLocationRegion + '\'' +
                ", buildingName='" + buildingName + '\'' +
                ", latitude=" + latitude +
                ", longitude=" + longitude +
                ", currentRegions=" + currentRegions +
                '}';
    }
}
